from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="UserSchemaOut")


@_attrs_define
class UserSchemaOut:
    """
    Attributes:
        name (str):
        username (str):
        email (str):
        created_at (float):
        updated_at (float):
        allowed_actions (list[str]):
    """

    name: str
    username: str
    email: str
    created_at: float
    updated_at: float
    allowed_actions: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        username = self.username

        email = self.email

        created_at = self.created_at

        updated_at = self.updated_at

        allowed_actions = self.allowed_actions

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "name": name,
            "username": username,
            "email": email,
            "created_at": created_at,
            "updated_at": updated_at,
            "allowed_actions": allowed_actions,
        })

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        username = d.pop("username")

        email = d.pop("email")

        created_at = d.pop("created_at")

        updated_at = d.pop("updated_at")

        allowed_actions = cast(list[str], d.pop("allowed_actions"))

        user_schema_out = cls(
            name=name,
            username=username,
            email=email,
            created_at=created_at,
            updated_at=updated_at,
            allowed_actions=allowed_actions,
        )

        user_schema_out.additional_properties = d
        return user_schema_out

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# This file is auto-generated by OpenAPI Python Client.
# Do not edit manually.

from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.action_schema_out import ActionSchemaOut
from ...models.action_status import ActionStatus
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    status: ActionStatus | None | Unset = UNSET,
    action_user: None | Unset | str = UNSET,
    max_age_minutes: None | Unset | int = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_status: None | Unset | str
    if isinstance(status, Unset):
        json_status = UNSET
    elif isinstance(status, ActionStatus):
        json_status = status.value
    else:
        json_status = status
    params["status"] = json_status

    json_action_user: None | Unset | str
    if isinstance(action_user, Unset):
        json_action_user = UNSET
    else:
        json_action_user = action_user
    params["action_user"] = json_action_user

    json_max_age_minutes: None | Unset | int
    if isinstance(max_age_minutes, Unset):
        json_max_age_minutes = UNSET
    else:
        json_max_age_minutes = max_age_minutes
    params["max_age_minutes"] = json_max_age_minutes

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/actions",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> HTTPValidationError | list["ActionSchemaOut"] | None:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = ActionSchemaOut.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[HTTPValidationError | list["ActionSchemaOut"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    status: ActionStatus | None | Unset = UNSET,
    action_user: None | Unset | str = UNSET,
    max_age_minutes: None | Unset | int = UNSET,
) -> Response[HTTPValidationError | list["ActionSchemaOut"]]:
    """Action List

     Lists actions, optionally filtered by status, user, or age.

    Args:
        status (Union[ActionStatus, None, Unset]): Filter actions by their status
        action_user (Union[None, Unset, str]): Filter actions by username instead of the current
            authenticated user
        max_age_minutes (Union[None, Unset, int]): Filter actions by their age in minutes. Actions
            updated more than this many minutes ago will be excluded.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['ActionSchemaOut']]]
    """

    kwargs = _get_kwargs(
        status=status,
        action_user=action_user,
        max_age_minutes=max_age_minutes,
    )

    with client as _client:
        response = _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient | Client,
    status: ActionStatus | None | Unset = UNSET,
    action_user: None | Unset | str = UNSET,
    max_age_minutes: None | Unset | int = UNSET,
) -> HTTPValidationError | list["ActionSchemaOut"] | None:
    """Action List

     Lists actions, optionally filtered by status, user, or age.

    Args:
        status (Union[ActionStatus, None, Unset]): Filter actions by their status
        action_user (Union[None, Unset, str]): Filter actions by username instead of the current
            authenticated user
        max_age_minutes (Union[None, Unset, int]): Filter actions by their age in minutes. Actions
            updated more than this many minutes ago will be excluded.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['ActionSchemaOut']]
    """

    return sync_detailed(
        client=client,
        status=status,
        action_user=action_user,
        max_age_minutes=max_age_minutes,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    status: ActionStatus | None | Unset = UNSET,
    action_user: None | Unset | str = UNSET,
    max_age_minutes: None | Unset | int = UNSET,
) -> Response[HTTPValidationError | list["ActionSchemaOut"]]:
    """Action List

     Lists actions, optionally filtered by status, user, or age.

    Args:
        status (Union[ActionStatus, None, Unset]): Filter actions by their status
        action_user (Union[None, Unset, str]): Filter actions by username instead of the current
            authenticated user
        max_age_minutes (Union[None, Unset, int]): Filter actions by their age in minutes. Actions
            updated more than this many minutes ago will be excluded.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['ActionSchemaOut']]]
    """

    kwargs = _get_kwargs(
        status=status,
        action_user=action_user,
        max_age_minutes=max_age_minutes,
    )

    async with client as _client:
        response = await _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    status: ActionStatus | None | Unset = UNSET,
    action_user: None | Unset | str = UNSET,
    max_age_minutes: None | Unset | int = UNSET,
) -> HTTPValidationError | list["ActionSchemaOut"] | None:
    """Action List

     Lists actions, optionally filtered by status, user, or age.

    Args:
        status (Union[ActionStatus, None, Unset]): Filter actions by their status
        action_user (Union[None, Unset, str]): Filter actions by username instead of the current
            authenticated user
        max_age_minutes (Union[None, Unset, int]): Filter actions by their age in minutes. Actions
            updated more than this many minutes ago will be excluded.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['ActionSchemaOut']]
    """

    return (
        await asyncio_detailed(
            client=client,
            status=status,
            action_user=action_user,
            max_age_minutes=max_age_minutes,
        )
    ).parsed


from typing import Annotated

import typer

app = typer.Typer()


@app.command(help="""Lists actions, optionally filtered by status, user, or age.""")
def action_list(
    ctx: typer.Context,
    status: Annotated[
        ActionStatus | None, typer.Option(help="Filter actions by their status")
    ] = None,
    action_user: Annotated[
        None | str,
        typer.Option(
            help="Filter actions by username instead of the current authenticated user"
        ),
    ] = None,
    max_age_minutes: Annotated[
        None | int,
        typer.Option(
            help="Filter actions by their age in minutes. Actions updated more than this many minutes ago will be excluded."
        ),
    ] = None,
) -> None:
    result = sync(
        status=status,
        action_user=action_user,
        max_age_minutes=max_age_minutes,
        client=ctx.obj["client"],
    )
    if "formatter" in ctx.obj and result:
        output: Any = result
        if isinstance(result, list):
            output = [
                item.to_dict() if hasattr(item, "to_dict") else item for item in result
            ]
        elif hasattr(result, "to_dict"):
            output = result.to_dict()
        ctx.obj["formatter"](output)



# This file is auto-generated by OpenAPI Python Client.
# Do not edit manually.

from . import (
    action_cancel,
    action_detail,
    action_list,
    create_token,
    external_resource_rds_reboot,
    me,
    no_op,
    openshift_workload_restart,
)

__all__ = [
    "action_cancel",
    "action_detail",
    "action_list",
    "create_token",
    "external_resource_rds_reboot",
    "me",
    "no_op",
    "openshift_workload_restart",
]



# This file is auto-generated by OpenAPI Python Client.
# Do not edit manually.

from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.action_schema_out import ActionSchemaOut
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    action_id: str,
) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/actions/{action_id}",
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> ActionSchemaOut | HTTPValidationError | None:
    if response.status_code == 202:
        response_202 = ActionSchemaOut.from_dict(response.json())

        return response_202
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[ActionSchemaOut | HTTPValidationError]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    action_id: str,
    *,
    client: AuthenticatedClient | Client,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """Action Cancel

     Cancels a pending or running action by its ID.

    Args:
        action_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        action_id=action_id,
    )

    with client as _client:
        response = _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


def sync(
    action_id: str,
    *,
    client: AuthenticatedClient | Client,
) -> ActionSchemaOut | HTTPValidationError | None:
    """Action Cancel

     Cancels a pending or running action by its ID.

    Args:
        action_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return sync_detailed(
        action_id=action_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    action_id: str,
    *,
    client: AuthenticatedClient | Client,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """Action Cancel

     Cancels a pending or running action by its ID.

    Args:
        action_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        action_id=action_id,
    )

    async with client as _client:
        response = await _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


async def asyncio(
    action_id: str,
    *,
    client: AuthenticatedClient | Client,
) -> ActionSchemaOut | HTTPValidationError | None:
    """Action Cancel

     Cancels a pending or running action by its ID.

    Args:
        action_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            action_id=action_id,
            client=client,
        )
    ).parsed


from typing import Annotated

import typer

app = typer.Typer()


@app.command(help="""Cancels a pending or running action by its ID.""")
def action_cancel(
    ctx: typer.Context,
    action_id: Annotated[str, typer.Option(help="", show_default=False)],
) -> None:
    result = sync(action_id=action_id, client=ctx.obj["client"])
    if "formatter" in ctx.obj and result:
        output: Any = result
        if isinstance(result, list):
            output = [
                item.to_dict() if hasattr(item, "to_dict") else item for item in result
            ]
        elif hasattr(result, "to_dict"):
            output = result.to_dict()
        ctx.obj["formatter"](output)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.action_status import ActionStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.action_schema_out_task_args import ActionSchemaOutTaskArgs


T = TypeVar("T", bound="ActionSchemaOut")


@_attrs_define
class ActionSchemaOut:
    """
    Attributes:
        name (str):
        owner (str):
        action_id (str):
        created_at (float):
        updated_at (float):
        status (Union[Unset, ActionStatus]):
        result (Union[None, Unset, str]):
        task_args (Union[Unset, ActionSchemaOutTaskArgs]):
    """

    name: str
    owner: str
    action_id: str
    created_at: float
    updated_at: float
    status: Unset | ActionStatus = UNSET
    result: None | Unset | str = UNSET
    task_args: Union[Unset, "ActionSchemaOutTaskArgs"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        owner = self.owner

        action_id = self.action_id

        created_at = self.created_at

        updated_at = self.updated_at

        status: Unset | str = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        result: None | Unset | str
        if isinstance(self.result, Unset):
            result = UNSET
        else:
            result = self.result

        task_args: Unset | dict[str, Any] = UNSET
        if not isinstance(self.task_args, Unset):
            task_args = self.task_args.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "name": name,
            "owner": owner,
            "action_id": action_id,
            "created_at": created_at,
            "updated_at": updated_at,
        })
        if status is not UNSET:
            field_dict["status"] = status
        if result is not UNSET:
            field_dict["result"] = result
        if task_args is not UNSET:
            field_dict["task_args"] = task_args

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.action_schema_out_task_args import ActionSchemaOutTaskArgs

        d = dict(src_dict)
        name = d.pop("name")

        owner = d.pop("owner")

        action_id = d.pop("action_id")

        created_at = d.pop("created_at")

        updated_at = d.pop("updated_at")

        _status = d.pop("status", UNSET)
        status: Unset | ActionStatus
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = ActionStatus(_status)

        def _parse_result(data: object) -> None | Unset | str:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | Unset | str, data)

        result = _parse_result(d.pop("result", UNSET))

        _task_args = d.pop("task_args", UNSET)
        task_args: Unset | ActionSchemaOutTaskArgs
        if isinstance(_task_args, Unset):
            task_args = UNSET
        else:
            task_args = ActionSchemaOutTaskArgs.from_dict(_task_args)

        action_schema_out = cls(
            name=name,
            owner=owner,
            action_id=action_id,
            created_at=created_at,
            updated_at=updated_at,
            status=status,
            result=result,
            task_args=task_args,
        )

        action_schema_out.additional_properties = d
        return action_schema_out

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .action_schema_out import ActionSchemaOut
from .action_schema_out_task_args import ActionSchemaOutTaskArgs
from .action_status import ActionStatus
from .create_token_param import CreateTokenParam
from .http_validation_error import HTTPValidationError
from .openshift_workload_restart_kind import OpenshiftWorkloadRestartKind
from .user_schema_out import UserSchemaOut
from .validation_error import ValidationError

__all__ = (
    "ActionSchemaOut",
    "ActionSchemaOutTaskArgs",
    "ActionStatus",
    "CreateTokenParam",
    "HTTPValidationError",
    "OpenshiftWorkloadRestartKind",
    "UserSchemaOut",
    "ValidationError",
)



from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.action_schema_out import ActionSchemaOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    account: str,
    identifier: str,
    *,
    force_failover: Unset | bool = False,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["force_failover"] = force_failover

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/external-resource/rds-reboot/{account}/{identifier}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> ActionSchemaOut | HTTPValidationError | None:
    if response.status_code == 202:
        response_202 = ActionSchemaOut.from_dict(response.json())

        return response_202
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[ActionSchemaOut | HTTPValidationError]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
    force_failover: Unset | bool = False,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """External Resource Rds Reboot

     Reboot an RDS instance.

    This action initiates a reboot of a specified RDS instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier
        force_failover (Union[Unset, bool]): Enforce DB failover. Your RDS must be confiugred for
            Multi-AZ! Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        account=account,
        identifier=identifier,
        force_failover=force_failover,
    )

    with client as _client:
        response = _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


def sync(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
    force_failover: Unset | bool = False,
) -> ActionSchemaOut | HTTPValidationError | None:
    """External Resource Rds Reboot

     Reboot an RDS instance.

    This action initiates a reboot of a specified RDS instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier
        force_failover (Union[Unset, bool]): Enforce DB failover. Your RDS must be confiugred for
            Multi-AZ! Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return sync_detailed(
        account=account,
        identifier=identifier,
        client=client,
        force_failover=force_failover,
    ).parsed


async def asyncio_detailed(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
    force_failover: Unset | bool = False,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """External Resource Rds Reboot

     Reboot an RDS instance.

    This action initiates a reboot of a specified RDS instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier
        force_failover (Union[Unset, bool]): Enforce DB failover. Your RDS must be confiugred for
            Multi-AZ! Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        account=account,
        identifier=identifier,
        force_failover=force_failover,
    )

    async with client as _client:
        response = await _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


async def asyncio(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
    force_failover: Unset | bool = False,
) -> ActionSchemaOut | HTTPValidationError | None:
    """External Resource Rds Reboot

     Reboot an RDS instance.

    This action initiates a reboot of a specified RDS instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier
        force_failover (Union[Unset, bool]): Enforce DB failover. Your RDS must be confiugred for
            Multi-AZ! Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            account=account,
            identifier=identifier,
            client=client,
            force_failover=force_failover,
        )
    ).parsed


from typing import Annotated

import typer

app = typer.Typer()


@app.command(
    help="""Reboot an RDS instance.

This action initiates a reboot of a specified RDS instance in a given AWS account."""
)
def external_resource_rds_reboot(
    ctx: typer.Context,
    account: Annotated[str, typer.Option(help="AWS account name", show_default=False)],
    identifier: Annotated[
        str, typer.Option(help="RDS instance identifier", show_default=False)
    ],
    force_failover: Annotated[
        bool,
        typer.Option(
            help="Enforce DB failover. Your RDS must be confiugred for Multi-AZ!"
        ),
    ] = False,
) -> None:
    result = sync(
        account=account,
        identifier=identifier,
        force_failover=force_failover,
        client=ctx.obj["client"],
    )
    if "formatter" in ctx.obj and result:
        output: Any = result
        if isinstance(result, list):
            output = [
                item.to_dict() if hasattr(item, "to_dict") else item for item in result
            ]
        elif hasattr(result, "to_dict"):
            output = result.to_dict()
        ctx.obj["formatter"](output)



from enum import Enum


class OpenshiftWorkloadRestartKind(str, Enum):
    DAEMONSET = "DaemonSet"
    DEPLOYMENT = "Deployment"
    POD = "Pod"
    STATEFULSET = "StatefulSet"

    def __str__(self) -> str:
        return str(self.value)
